pub struct Repo {
pub name: String,
pub path: String,
pub private: Option<bool>,
pub url: String,
pub git: String,
pub description: Option<String>,
}Expand description
Repo (repository)
Represents a repository for any platform it contains varios properties that are shared across all the repositories.
Fields
name: Stringpath: Stringprivate: Option<bool>url: Stringgit: Stringdescription: Option<String>Implementations